==> okteta-14.11.90.tar.xz: okteta-14.11.90/kasten/core/io/filesystem/bytearrayrawfilesynchronizer.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2007 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYRAWFILESYNCHRONIZER_H
#define BYTEARRAYRAWFILESYNCHRONIZER_H

// lib
#include "oktetakastencore_export.h"
// Kasten core
#include <abstractmodelfilesystemsynchronizer.h>


namespace Kasten
{

class ByteArrayDocument;

class OKTETAKASTENCORE_EXPORT ByteArrayRawFileSynchronizer : public AbstractModelFileSystemSynchronizer
{
    Q_OBJECT

  friend class ByteArrayRawFileLoadJob;
  friend class ByteArrayRawFileConnectJob;

  public:
    ByteArrayRawFileSynchronizer();

  public: // AbstractModelSynchronizer API
    virtual AbstractLoadJob *startLoad( const QUrl &url ) Q_DECL_OVERRIDE;
    virtual AbstractSyncToRemoteJob *startSyncToRemote() Q_DECL_OVERRIDE;
    virtual AbstractSyncFromRemoteJob *startSyncFromRemote() Q_DECL_OVERRIDE;
    virtual AbstractSyncWithRemoteJob *startSyncWithRemote( const QUrl& url, AbstractModelSynchronizer::ConnectOption option ) Q_DECL_OVERRIDE;
    virtual AbstractConnectJob *startConnect( AbstractDocument* document,
                                              const QUrl& url, AbstractModelSynchronizer::ConnectOption option ) Q_DECL_OVERRIDE;

    virtual AbstractDocument* document() const;

    virtual LocalSyncState localSyncState() const;

  protected:
    void setDocument( ByteArrayDocument *document );

  private Q_SLOTS:
    void onUrlChange( const QUrl &url );
    void onModelModified( bool isModified );

  private:
    ByteArrayDocument *mDocument;
};

}

#endif

==> okteta-15.04.3.tar.xz: okteta-15.04.3/kasten/core/io/filesystem/bytearrayrawfilesynchronizer.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2007 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYRAWFILESYNCHRONIZER_H
#define BYTEARRAYRAWFILESYNCHRONIZER_H

// lib
#include <kasten/okteta/oktetakastencore_export.h>
// Kasten core
#include <kasten/abstractmodelfilesystemsynchronizer.h>


namespace Kasten
{

class ByteArrayDocument;

class OKTETAKASTENCORE_EXPORT ByteArrayRawFileSynchronizer : public AbstractModelFileSystemSynchronizer
{
    Q_OBJECT

  friend class ByteArrayRawFileLoadJob;
  friend class ByteArrayRawFileConnectJob;

  public:
    ByteArrayRawFileSynchronizer();

  public: // AbstractModelSynchronizer API
    virtual AbstractLoadJob *startLoad( const QUrl &url ) Q_DECL_OVERRIDE;
    virtual AbstractSyncToRemoteJob *startSyncToRemote() Q_DECL_OVERRIDE;
    virtual AbstractSyncFromRemoteJob *startSyncFromRemote() Q_DECL_OVERRIDE;
    virtual AbstractSyncWithRemoteJob *startSyncWithRemote( const QUrl& url, AbstractModelSynchronizer::ConnectOption option ) Q_DECL_OVERRIDE;
    virtual AbstractConnectJob *startConnect( AbstractDocument* document,
                                              const QUrl& url, AbstractModelSynchronizer::ConnectOption option ) Q_DECL_OVERRIDE;

    virtual AbstractDocument* document() const;

    virtual LocalSyncState localSyncState() const;

  protected:
    void setDocument( ByteArrayDocument *document );

  private Q_SLOTS:
    void onUrlChange( const QUrl &url );
    void onModelModified( bool isModified );

  private:
    ByteArrayDocument *mDocument;
};

}

#endif
